summaryrefslogtreecommitdiff
path: root/chromium/third_party/blink/renderer/modules/webdatabase/database_context.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/third_party/blink/renderer/modules/webdatabase/database_context.cc')
-rw-r--r--chromium/third_party/blink/renderer/modules/webdatabase/database_context.cc14
1 files changed, 7 insertions, 7 deletions
diff --git a/chromium/third_party/blink/renderer/modules/webdatabase/database_context.cc b/chromium/third_party/blink/renderer/modules/webdatabase/database_context.cc
index a77f1304e75..a026b224bd7 100644
--- a/chromium/third_party/blink/renderer/modules/webdatabase/database_context.cc
+++ b/chromium/third_party/blink/renderer/modules/webdatabase/database_context.cc
@@ -69,8 +69,8 @@ namespace blink {
// 1. "outlive" the ExecutionContext.
// - This is needed because the DatabaseContext needs to remove itself from
// the
// ExecutionContext's ContextLifecycleObserver list and
// ContextLifecycleObserver
// list. This removal needs to be executed on the script's thread. Hence,
// we
// rely on the ExecutionContext's shutdown process to call
@@ -99,7 +99,7 @@ DatabaseContext* DatabaseContext::Create(ExecutionContext* context) {
}
DatabaseContext::DatabaseContext(ExecutionContext* context)
- : ContextLifecycleObserver(context),
+ : ExecutionContextLifecycleObserver(context),
has_open_databases_(false),
has_requested_termination_(false) {
DCHECK(IsMainThread());
@@ -115,9 +115,9 @@ DatabaseContext::~DatabaseContext() {
DatabaseManager::Manager().DidDestructDatabaseContext();
}
-void DatabaseContext::Trace(blink::Visitor* visitor) {
+void DatabaseContext::Trace(Visitor* visitor) {
visitor->Trace(database_thread_);
- ContextLifecycleObserver::Trace(visitor);
+ ExecutionContextLifecycleObserver::Trace(visitor);
}
// This is called if the associated ExecutionContext is destructing while
@@ -125,7 +125,7 @@ void DatabaseContext::Trace(blink::Visitor* visitor) {
// To do this, we stop the database and let everything shutdown naturally
// because the database closing process may still make use of this context.
// It is not safe to just delete the context here.
-void DatabaseContext::ContextDestroyed(ExecutionContext*) {
+void DatabaseContext::ContextDestroyed() {
StopDatabases();
DatabaseManager::Manager().UnregisterDatabaseContext(this);
}
@@ -175,7 +175,7 @@ void DatabaseContext::StopDatabases() {
}
bool DatabaseContext::AllowDatabaseAccess() const {
- return To<Document>(GetExecutionContext())->IsActive();
+ return Document::From(GetExecutionContext())->IsActive();
}
const SecurityOrigin* DatabaseContext::GetSecurityOrigin() const {
@@ -69,8 +69,8 @@ namespace blink {
// - This is needed because the DatabaseContext needs to remove itself from
// the
-// ExecutionContext's ContextLifecycleObserver list and
-// ContextLifecycleObserver
+// ExecutionContext's ExecutionContextLifecycleObserver list and
+// ExecutionContextLifecycleObserver
// list. This removal needs to be executed on the script's thread. Hence,
// we